***************************
* File: A_B_C.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P E\"
capture clear
capture log close
clear
set mem 700m
set more off

use "4- Data\4.1. Raw Data\First Round\cisco\A_B_C.dta"

**************************************************
***   Ensure all variables are present and labeled.
**************************************************
log using "A_B_C", replace
codebook, compact
log close

**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "A_B_C", replace

**************************************************
***   Unique identifiers: ID
**************************************************
egen cisco_code = group(cisco)
order cisco cisco_code

**************************************************
***  Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.

foreach v of varlist       exced_caisse{
	gen error01`v' = (caisse_suffi== 1 & `v'< . )
} 
foreach v of varlist       repar_caisse exced_caisse{
	gen error02`v' = (caisse_suffi== 2 & `v'< . )
} 
foreach v of varlist      insuf_caisse {
	gen error02`v' = (caisse_suffi== 2 & `v'< "" )
} 
foreach v of varlist       repar_caisse {
	gen error03`v' = (caisse_suffi== 3 & `v'< . )
}
foreach v of varlist      insuf_caisse {
	gen error03`v' = (caisse_suffi== 3 & `v'< "" )
} 

**************************************************
***  Identify illegal responses
**************************************************

log using "A_B_C label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************

log using "A_B_C grubbs", replace
preserve
global discrete (	chgt_nosubv	comment_subv2	comment_subv1	per_ensgt	chgt_ensgt	exced_subv	repar_subv	comment_cais2	comment_cais1	exced_caisse	repar_caisse	subv_suffi	caisse_suffi	trs_tresor	trs_cirfin	trs_dren	poste7	poste6	poste5	poste4	poste3	poste2	poste1	fonct7	fonct6	fonct5	fonct4	fonct3	fonct2	fonct1 )
global name ( cisco dren insuf_caisse insuf_subv nom_rep*)
drop $discrete $name 
mvdecode _all, mv(0 = .z)
grubbs _all, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)
log close
restore 

**************************************************
***  Identify errors to be reviewed
**************************************************
drop err* 

replace exced_caisse=. if cisco_code==24 | cisco_code==4
replace trs_cirfin=. if trs_cirfin==0
**************************************************
*** FINAL  : Delivrables
**************************************************

*Codebook
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.3. Data Code Book\First Round\cisco"
log using "A_B_C codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\Madagascar 2006 P E\4- Data\4.3. Clean Data\4.3.1. Final Data\First Round\cisco"
save "A_B_C_cleaned_data.dta", replace
